# Changelog

## [1.1.0] - 02/10/2025

### Added

- Progress bar to show simulation progress
- Examples and utilities for performing montecarlo explorations of design variations, see `Manufacturing variability.ipynb`

### Removed

- Incorrect cell and link in the example notebook `01 Getting Started.ipynb`

## [1.0.2] - 25/09/2025

### Fixed

- Fixed possible timeout when running a large number of simulations at once


## [1.0.0] - 16/09/2025

- Breathe Design is released.
